Package: IntramiRExploreR
Title: Predicting Targets for Drosophila Intragenic miRNAs
Version: 1.35.0
Author: Surajit Bhattacharya and Daniel Cox
Maintainer: Surajit Bhattacharya <sbhattach2@childrensnational.org>
Description: Intra-miR-ExploreR, an integrative miRNA target prediction
    bioinformatics tool, identifies targets combining expression and biophysical
    interactions of a given microRNA (miR). Using the tool, we have identified
    targets for 92 intragenic miRs in D. melanogaster, using available microarray
    expression data, from Affymetrix 1 and Affymetrix2 microarray array platforms,
    providing a global perspective of intragenic miR targets in Drosophila.
    Predicted targets are grouped according to biological functions using the DAVID
    Gene Ontology tool and are ranked based on a biologically relevant scoring
    system, enabling the user to identify functionally relevant targets for a given
    miR.
Depends: R (>= 3.4)
Imports: igraph (>= 1.0.1), FGNet (>= 3.0.7), knitr (>= 1.12.3), stats,
        utils, grDevices, graphics
Suggests: gProfileR, topGO, org.Dm.eg.db, rmarkdown, testthat
VignetteBuilder: knitr
License: GPL-2
biocViews: Software, Microarray, GeneTarget, StatisticalMethod,
        GeneExpression, GenePrediction
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.2
URL: https://github.com/VilainLab/IntramiRExploreR
BugReports: https://github.com/VilainLab/IntramiRExploreR
git_url: https://git.bioconductor.org/packages/IntramiRExploreR
git_branch: devel
git_last_commit: 2400d90
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:18:59 UTC; biocbuild
