# Generated by roxygen2: do not edit by hand

export(Gene_Visualisation)
export(GetGOS_ALL)
export(Visualisation)
export(extract_HostGene)
export(extract_intragenic_miR)
export(genes_Stat)
export(miRTargets_Stat)
import(FGNet)
import(grDevices)
import(graphics)
import(igraph)
import(knitr)
import(utils)
importFrom(stats,na.omit)
