#' IntramiRExploreR:Prediction of targets for Intragenic 
#' miRNA in Drosophila.
#'
#' Prediction of targets for Drosophila Intragenic microRNAs
#' and Integrated approach using Gene Ontology and Networking tools.
#'
#' @import knitr
#' @examples
#'\dontrun{
#' gene='Gmap'
#' extract_intragenic_miR(gene)
#' }
#' @docType package
#' @name IntramiRExploreR
NULL
# > [1] '_PACKAGE' 
